==> tap-parser-1.1.1.tgz: package/test/fixtures/indent.js <==
module.exports =
[ [ 'line', 'TAP Version 13\n' ],
  [ 'version', '13' ],
  [ 'line', '1..2\n' ],
  [ 'plan', { start: 1, end: 2 } ],
  [ 'line', '# nesting\n' ],
  [ 'comment', '# nesting\n' ],
  [ 'line', '    1..2\n' ],
  [ 'child',
    [ [ 'line', '1..2\n' ],
      [ 'plan', { start: 1, end: 2 } ],
      [ 'line', 'ok 1 - true is ok # time=1.234ms\n' ],
      [ 'line', 'ok 2 - doag is also okay # time=1.234ms\n' ],
      [ 'assert',
        { ok: true, id: 1, time: 1.234, name: 'true is ok' } ],
      [ 'assert',
        { ok: true, id: 2, time: 1.234, name: 'doag is also okay' } ],
      [ 'complete',
        { ok: true, count: 2, pass: 2, plan: { start: 1, end: 2 } } ] ] ],
  [ 'line', '    ok 1 - true is ok # time=1.234ms\n' ],
  [ 'line', '    ok 2 - doag is also okay # time=1.234ms\n' ],
  [ 'line', 'ok 1 - first # time=2.589ms\n' ],
  [ 'line', '    ok 1 - no plan # time=1.001ms\n' ],
  [ 'assert', { ok: true, id: 1, time: 2.589, name: 'first' } ],
  [ 'child',
    [ [ 'line', 'ok 1 - no plan # time=1.001ms\n' ],
      [ 'line', '    1..3\n' ],
      [ 'assert', { ok: true, id: 1, time: 1.001, name: 'no plan' } ],
      [ 'child',
        [ [ 'line', '1..3\n' ],
          [ 'plan', { start: 1, end: 3 } ],
          [ 'line', 'not ok granddaughter # SKIP for no raisin\n' ],
          [ 'line', 'ok grandson # time=1.001ms\n' ],
          [ 'assert',
            { ok: false, id: 1, skip: 'for no raisin', name: 'granddaughter' } ],
          [ 'line', '  ---\n' ],
          [ 'line', '  ok: 1\n' ],
          [ 'line', '  this: is not tap\n' ],
          [ 'line', '  it: is yaml\n' ],
          [ 'line', '  ...\n' ],
          [ 'assert',
            { ok: true,
              id: 2,
              time: 1.001,
              name: 'grandson',
              diag: { ok: 1, this: 'is not tap', it: 'is yaml' } } ],
          [ 'line', 'not ok grandchild # TODO\n' ],
          [ 'line', '  ---\n' ],
          [ 'line', '  ok: 1\n' ],
          [ 'line', '  this: is not tap or yaml\n' ],
          [ 'line', '  it: is garbage\n' ],
          [ 'extra',
            '  ok: 1\n  this: is not tap or yaml\n  it: is garbage\n' ],
          [ 'assert',
            { ok: false, id: 3, todo: true, name: 'grandchild' } ],
          [ 'complete',
            { ok: true,
              count: 3,
              pass: 1,
              fail: 2,
              todo: 1,
              skip: 1,
              plan: { start: 1, end: 3 } } ] ] ],
      [ 'line', '    not ok granddaughter # SKIP for no raisin\n' ],
      [ 'line', '    ok grandson # time=1.001ms\n' ],
      [ 'line', '      ---\n' ],
      [ 'line', '      ok: 1\n' ],
      [ 'line', '      this: is not tap\n' ],
      [ 'line', '      it: is yaml\n' ],
      [ 'line', '      ...\n' ],
      [ 'line', '    not ok grandchild # TODO\n' ],
      [ 'line', '      ---\n' ],
      [ 'line', '      ok: 1\n' ],
      [ 'line', '      this: is not tap or yaml\n' ],
      [ 'line', '      it: is garbage\n' ],
      [ 'line', 'ok 2 - this passes # time=1.200ms\n' ],
      [ 'line', '1..2\n' ],
      [ 'assert',
        { ok: true, id: 2, time: 1.2, name: 'this passes' } ],
      [ 'plan', { start: 1, end: 2 } ],
      [ 'complete',
        { ok: true, count: 2, pass: 2, plan: { start: 1, end: 2 } } ] ] ],
  [ 'line', '        1..3\n' ],
  [ 'line',
    '        not ok granddaughter # SKIP for no raisin\n' ],
  [ 'line', '        ok grandson # time=1.001ms\n' ],
  [ 'line', '          ---\n' ],
  [ 'line', '          ok: 1\n' ],
  [ 'line', '          this: is not tap\n' ],
  [ 'line', '          it: is yaml\n' ],
  [ 'line', '          ...\n' ],
  [ 'line', '        not ok grandchild # TODO\n' ],
  [ 'line', '          ---\n' ],
  [ 'line', '          ok: 1\n' ],
  [ 'line', '          this: is not tap or yaml\n' ],
  [ 'line', '          it: is garbage\n' ],
  [ 'line', '    ok 2 - this passes # time=1.200ms\n' ],
  [ 'line', '    1..2\n' ],
  [ 'line', 'ok 2 - second # time=1.200ms\n' ],
  [ 'assert', { ok: true, id: 2, time: 1.2, name: 'second' } ],
  [ 'complete',
    { ok: true, count: 2, pass: 2, plan: { start: 1, end: 2 } } ] ]

==> tap-parser-1.1.5.tgz: package/test/fixtures/indent.js <==
module.exports =
[ [ 'line', 'TAP Version 13\n' ],
  [ 'version', '13' ],
  [ 'line', '1..2\n' ],
  [ 'plan', { start: 1, end: 2 } ],
  [ 'line', '# nesting\n' ],
  [ 'comment', '# nesting\n' ],
  [ 'line', '    # Subtest: first\n' ],
  [ 'child',
    [ [ 'line', '# Subtest: first\n' ],
      [ 'comment', '# Subtest: first\n' ],
      [ 'line', '1..2\n' ],
      [ 'plan', { start: 1, end: 2 } ],
      [ 'line', 'ok 1 - true is ok # time=1.234ms\n' ],
      [ 'line', 'ok 2 - doag is also okay # time=1.234ms\n' ],
      [ 'assert',
        { ok: true, id: 1, time: 1.234, name: 'true is ok' } ],
      [ 'assert',
        { ok: true, id: 2, time: 1.234, name: 'doag is also okay' } ],
      [ 'complete',
        { ok: true, count: 2, pass: 2, plan: { start: 1, end: 2 } } ] ] ],
  [ 'line', '    1..2\n' ],
  [ 'line', '    ok 1 - true is ok # time=1.234ms\n' ],
  [ 'line', '    ok 2 - doag is also okay # time=1.234ms\n' ],
  [ 'line', 'ok 1 - first # time=2.589ms\n' ],
  [ 'line', '    # Subtest: second\n' ],
  [ 'assert', { ok: true, id: 1, time: 2.589, name: 'first' } ],
  [ 'child',
    [ [ 'line', '# Subtest: second\n' ],
      [ 'comment', '# Subtest: second\n' ],
      [ 'line', 'ok 1 - no plan # time=1.001ms\n' ],
      [ 'line', '    # Subtest: this passes\n' ],
      [ 'assert', { ok: true, id: 1, time: 1.001, name: 'no plan' } ],
      [ 'child',
        [ [ 'line', '# Subtest: this passes\n' ],
          [ 'comment', '# Subtest: this passes\n' ],
          [ 'line', '1..3\n' ],
          [ 'plan', { start: 1, end: 3 } ],
          [ 'line', 'not ok granddaughter # SKIP for no raisin\n' ],
          [ 'line', 'ok grandson # time=1.001ms\n' ],
          [ 'assert',
            { ok: false, id: 1, skip: 'for no raisin', name: 'granddaughter' } ],
          [ 'line', '  ---\n' ],
          [ 'line', '  ok: 1\n' ],
          [ 'line', '  this: is not tap\n' ],
          [ 'line', '  it: is yaml\n' ],
          [ 'line', '  ...\n' ],
          [ 'assert',
            { ok: true,
              id: 2,
              time: 1.001,
              name: 'grandson',
              diag: { ok: 1, this: 'is not tap', it: 'is yaml' } } ],
          [ 'line', 'not ok grandchild # TODO\n' ],
          [ 'line', '  ---\n' ],
          [ 'line', '  ok: 1\n' ],
          [ 'line', '  this: is not tap or yaml\n' ],
          [ 'line', '  it: is garbage\n' ],
          [ 'extra',
            '  ok: 1\n  this: is not tap or yaml\n  it: is garbage\n' ],
          [ 'assert',
            { ok: false, id: 3, todo: true, name: 'grandchild' } ],
          [ 'complete',
            { ok: true,
              count: 3,
              pass: 1,
              fail: 2,
              todo: 1,
              skip: 1,
              plan: { start: 1, end: 3 } } ] ] ],
      [ 'line', '    1..3\n' ],
      [ 'line', '    not ok granddaughter # SKIP for no raisin\n' ],
      [ 'line', '    ok grandson # time=1.001ms\n' ],
      [ 'line', '      ---\n' ],
      [ 'line', '      ok: 1\n' ],
      [ 'line', '      this: is not tap\n' ],
      [ 'line', '      it: is yaml\n' ],
      [ 'line', '      ...\n' ],
      [ 'line', '    not ok grandchild # TODO\n' ],
      [ 'line', '      ---\n' ],
      [ 'line', '      ok: 1\n' ],
      [ 'line', '      this: is not tap or yaml\n' ],
      [ 'line', '      it: is garbage\n' ],
      [ 'line', 'ok 2 - this passes # time=1.200ms\n' ],
      [ 'line', '1..2\n' ],
      [ 'assert',
        { ok: true, id: 2, time: 1.2, name: 'this passes' } ],
      [ 'plan', { start: 1, end: 2 } ],
      [ 'complete',
        { ok: true, count: 2, pass: 2, plan: { start: 1, end: 2 } } ] ] ],
  [ 'line', '    ok 1 - no plan # time=1.001ms\n' ],
  [ 'line', '        # Subtest: this passes\n' ],
  [ 'line', '        1..3\n' ],
  [ 'line',
    '        not ok granddaughter # SKIP for no raisin\n' ],
  [ 'line', '        ok grandson # time=1.001ms\n' ],
  [ 'line', '          ---\n' ],
  [ 'line', '          ok: 1\n' ],
  [ 'line', '          this: is not tap\n' ],
  [ 'line', '          it: is yaml\n' ],
  [ 'line', '          ...\n' ],
  [ 'line', '        not ok grandchild # TODO\n' ],
  [ 'line', '          ---\n' ],
  [ 'line', '          ok: 1\n' ],
  [ 'line', '          this: is not tap or yaml\n' ],
  [ 'line', '          it: is garbage\n' ],
  [ 'line', '    ok 2 - this passes # time=1.200ms\n' ],
  [ 'line', '    1..2\n' ],
  [ 'line', 'ok 2 - second # time=1.200ms\n' ],
  [ 'assert', { ok: true, id: 2, time: 1.2, name: 'second' } ],
  [ 'complete',
    { ok: true, count: 2, pass: 2, plan: { start: 1, end: 2 } } ] ]
